@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,6 +14,19 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 #include "gamelobbydialogimpl.h"
 #include "mygamelistsortfilterproxymodel.h"
@@ -27,35 +40,42 @@
 #include "game_defs.h"
 #include <net/socket_msg.h>
 #include "mymessagedialogimpl.h"
+#include "soundevents.h"
 
 using namespace std;
 
 
 gameLobbyDialogImpl::gameLobbyDialogImpl(startWindowImpl *parent, ConfigFile *c)
-	: QDialog(parent), myW(NULL), myStartWindow(parent), myConfig(c), currentGameName(""), myPlayerId(0), isGameAdministrator(false), inGame(false), guestMode(false), blinkingButtonAnimationState(true), myChat(NULL), keyUpCounter(0), infoMsgToShowId(0), currentInvitationGameId(0), inviteDialogIsCurrentlyShown(false), autoStartTimerCounter(0)
+	: QDialog(parent), myW(NULL), myStartWindow(parent), myConfig(c), currentGameName(""), myPlayerId(0), isGameAdministrator(false), inGame(false), guestMode(false), blinkingButtonAnimationState(true), myChat(NULL), keyUpCounter(0), infoMsgToShowId(0), currentInvitationGameId(0), inviteDialogIsCurrentlyShown(false), autoStartTimerCounter(0), lastNickListFilterState(0)
 {
 
 #ifdef __APPLE__
 	setWindowModality(Qt::ApplicationModal);
 	setWindowFlags(Qt::WindowSystemMenuHint | Qt::CustomizeWindowHint | Qt::Dialog);
+#elif _WIN32
+	setWindowFlags(Qt::Dialog | Qt::WindowMinimizeButtonHint);
 #endif
-	setupUi(this);
 
+	setupUi(this);
 	myAppDataPath = QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str());
 
 	//wait start game message
-	waitStartGameMsgBox = new QMessageBox(this);
+	waitStartGameMsgBox = new MyMessageBox(this);
 	waitStartGameMsgBox->setText(tr("Starting game. Please wait ..."));
+#ifndef ANDROID
 	waitStartGameMsgBox->setWindowModality(Qt::NonModal);
+#endif
 #ifdef __APPLE__
 	waitStartGameMsgBox->setWindowFlags(Qt::WindowSystemMenuHint | Qt::CustomizeWindowHint | Qt::Dialog);
 #endif
 	waitStartGameMsgBox->setStandardButtons(QMessageBox::NoButton);
 
 	//wait start game message for rejoin
-	waitRejoinStartGameMsgBox = new QMessageBox(this);
+	waitRejoinStartGameMsgBox = new MyMessageBox(this);
 	waitRejoinStartGameMsgBox->setText(tr("Waiting for the start of the next hand to rejoin the game ..."));
+#ifndef ANDROID
 	waitRejoinStartGameMsgBox->setWindowModality(Qt::NonModal);
+#endif
 #ifdef __APPLE__
 	waitRejoinStartGameMsgBox->setWindowFlags(Qt::WindowSystemMenuHint | Qt::CustomizeWindowHint | Qt::Dialog);
 #endif
@@ -63,6 +83,11 @@ gameLobbyDialogImpl::gameLobbyDialogImpl(startWindowImpl *parent, ConfigFile *c)
 
 	inviteOnlyInfoMsgBox = new myMessageDialogImpl(myConfig, this);
 
+	//HTML stuff
+	QString pokerthDotNet("<a href='http://www.pokerth.net'>http://www.pokerth.net</a>");
+	QString clickToRanking(QString("<a href='http://online-ranking.pokerth.net'>%1</a>").arg(tr("Click here to view the online rankings")));
+	label_pokerthDotNet->setText(pokerthDotNet);
+	label_rankings->setText(clickToRanking);
 
 	waitStartGameMsgBoxTimer = new QTimer(this);
 	waitStartGameMsgBoxTimer->setSingleShot(TRUE);
@@ -107,18 +132,46 @@ gameLobbyDialogImpl::gameLobbyDialogImpl(startWindowImpl *parent, ConfigFile *c)
 	myGameListSelectionModel = treeView_GameList->selectionModel();
 
 	QStringList headerList;
-	headerList << tr("Game") << tr("Players") << tr("State") << tr("T") << tr("P");
+	headerList << tr("Game") << tr("Players") << tr("State") << tr("T") << tr("P") << tr("Time");
 	myGameListModel->setHorizontalHeaderLabels(headerList);
 
-	treeView_GameList->setColumnWidth(0,190);
-	treeView_GameList->setColumnWidth(1,65);
-	treeView_GameList->setColumnWidth(2,65);
-	treeView_GameList->setColumnWidth(3,40);
-	treeView_GameList->setColumnWidth(4,40);
-
 #ifdef GUI_800x480
-	treeView_GameList->setStyleSheet("QTreeView {background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat; color:rgb(0, 0, 0); font: 14px}");
+	treeView_GameList->setColumnWidth(0,200); //484px alltogether
+	treeView_GameList->setColumnWidth(1,65);
+	treeView_GameList->setColumnWidth(2,100);
+	treeView_GameList->setColumnWidth(3,20);
+	treeView_GameList->setColumnWidth(4,20);
+	treeView_GameList->setColumnWidth(5,75);
+
+	treeView_GameList->setStyleSheet("QTreeView {background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat; color:rgb(0, 0, 0); font: 22px}");
+	treeView_GameList->header()->setStyleSheet("QObject {font: bold 18px}");
+
+	//make the scrollbars touchable for mobile guis
+	this->setStyleSheet("QScrollBar:vertical { border: 1px solid grey; background: #f0f0f0; width: 55px; margin: 1px -1px 0px 0px; } QScrollBar::handle:vertical { border-radius: 4px; border: 3px solid grey; background: LightGrey ; min-height: 60px; } QScrollBar::add-line:vertical { background: none; } QScrollBar::sub-line:vertical { background: none; } QScrollBar:up-arrow:vertical, QScrollBar::down-arrow:vertical { background: none; } QScrollBar::add-page:vertical, QScrollBar::sub-page:vertical { background: none; }");
+
+	//remove game type in game description field to save space
+	label_gameType->hide();
+	label_typeIcon->hide();
+	label_typeText->hide();
+
+	//set colors
+	QPalette p1;
+	p1.setColor(QPalette::WindowText, this->palette().color(QPalette::Link));
+	label_StartCash->setPalette(p1);
+	label_blindsList->setPalette(p1);
+	label_blindsRaiseIntervall->setPalette(p1);
+	label_blindsRaiseMode->setPalette(p1);
+	label_GameTiming->setPalette(p1);
+	label_SmallBlind->setPalette(p1);
+
 #else
+	treeView_GameList->setColumnWidth(0,190);
+	treeView_GameList->setColumnWidth(1,55);
+	treeView_GameList->setColumnWidth(2,65);
+	treeView_GameList->setColumnWidth(3,25);
+	treeView_GameList->setColumnWidth(4,25);
+	treeView_GameList->setColumnWidth(5,30);
+
 	treeView_GameList->setStyleSheet("QTreeView {background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat;}");
 #endif
 	treeView_GameList->setAutoFillBackground(TRUE);
@@ -149,10 +202,20 @@ gameLobbyDialogImpl::gameLobbyDialogImpl(startWindowImpl *parent, ConfigFile *c)
 	nickListPlayerInfoSubMenu->addAction(nickListPlayerInGameInfo);
 	nickListOpenPlayerStats1 = new QAction(QIcon(":/gfx/view-statistics.png"), tr("Show player stats"), nickListContextMenu);
 	nickListContextMenu->addAction(nickListOpenPlayerStats1);
+	nickListAdminSubMenu = nickListContextMenu->addMenu(tr("Admin action ..."));
+	nickListAdminTotalKickBan = new QAction(tr("Total kickban"), nickListAdminSubMenu);
+	nickListAdminSubMenu->addAction(nickListAdminTotalKickBan);
 
 	connectedPlayersListPlayerInfoSubMenu = new QMenu();
-	nickListOpenPlayerStats2 = new QAction(QIcon(":/gfx/view-statistics.png"), tr("Show player stats"), nickListContextMenu);
-	connectedPlayersListPlayerInfoSubMenu->addAction(nickListOpenPlayerStats2);
+	connectedPlayersListOpenPlayerStats = new QAction(QIcon(":/gfx/view-statistics.png"), tr("Show player stats"), connectedPlayersListPlayerInfoSubMenu);
+	connectedPlayersListPlayerInfoSubMenu->addAction(connectedPlayersListOpenPlayerStats);
+
+	gameListContextMenu = new QMenu();
+	gameListReportBadGameNameAction = new QAction(QIcon(":/gfx/emblem-important.png"), tr("Report inappropriate game name"), gameListContextMenu);
+	gameListContextMenu->addAction(gameListReportBadGameNameAction);
+	gameListAdminSubMenu = gameListContextMenu->addMenu(tr("Admin action ..."));
+	gameListAdminCloseGame = new QAction(tr("Close game"), gameListAdminSubMenu);
+	gameListAdminSubMenu->addAction(gameListAdminCloseGame);
 
 	connect( pushButton_CreateGame, SIGNAL( clicked() ), this, SLOT( createGame() ) );
 	connect( pushButton_JoinGame, SIGNAL( clicked() ), this, SLOT( joinGame() ) );
@@ -175,14 +238,19 @@ gameLobbyDialogImpl::gameLobbyDialogImpl(startWindowImpl *parent, ConfigFile *c)
 	connect( comboBox_nickListFilter, SIGNAL(currentIndexChanged(int)), this, SLOT(changeNickListFilter(int)));
 	connect( treeView_NickList, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT( showNickListContextMenu(QPoint) ) );
 	connect( treeWidget_connectedPlayers, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT( showConnectedPlayersContextMenu(QPoint) ) );
+	connect( treeView_GameList, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT( showGameListContextMenu(QPoint) ) );
 	connect( nickListInviteAction, SIGNAL(triggered()), this, SLOT( invitePlayerToCurrentGame() ));
 	connect( nickListIgnorePlayerAction, SIGNAL(triggered()), this, SLOT( putPlayerOnIgnoreList() ));
 	connect( nickListOpenPlayerStats1, SIGNAL(triggered()), this, SLOT( openPlayerStats1() ));
-	connect( nickListOpenPlayerStats2, SIGNAL(triggered()), this, SLOT( openPlayerStats2() ));
+	connect( connectedPlayersListOpenPlayerStats, SIGNAL(triggered()), this, SLOT( openPlayerStats2() ));
 	connect( lineEdit_searchForPlayers, SIGNAL(textChanged(QString)),this, SLOT(searchForPlayerRegExpChanged()));
+	connect( gameListReportBadGameNameAction, SIGNAL(triggered()), this, SLOT( reportBadGameName()));
+	connect( gameListAdminCloseGame, SIGNAL(triggered()), this, SLOT( adminActionCloseGame() ));
+	connect( nickListAdminTotalKickBan, SIGNAL(triggered()), this, SLOT( adminActionTotalKickBan() ));
 
 	lineEdit_searchForPlayers->installEventFilter(this);
 	lineEdit_ChatInput->installEventFilter(this);
+	this->installEventFilter(this);
 
 	clearDialog();
 
@@ -205,7 +273,9 @@ void gameLobbyDialogImpl::exec()
 		registeredUserMode();
 	}
 
-
+#ifdef ANDROID
+	this->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
+#endif
 	QDialog::exec();
 
 	waitStartGameMsgBoxTimer->stop();
@@ -281,7 +351,7 @@ void gameLobbyDialogImpl::createGame()
 		gameData.playerActionTimeoutSec = myCreateInternetGameDialog->spinBox_netTimeOutPlayerAction->value();
 		gameData.gameType = GameType(myCreateInternetGameDialog->comboBox_gameType->itemData(myCreateInternetGameDialog->comboBox_gameType->currentIndex(), Qt::UserRole).toInt());
 
-		currentGameName = myCreateInternetGameDialog->lineEdit_gameName->text();
+		currentGameName = myCreateInternetGameDialog->lineEdit_gameName->text().simplified();
 
 		switch (gameData.gameType) {
 		case GAME_TYPE_NORMAL: {
@@ -317,11 +387,14 @@ void gameLobbyDialogImpl::createGame()
 
 		updateDialogBlinds(gameData);
 
-		label_TimeoutForPlayerAction->setText(QString::number(gameData.playerActionTimeoutSec));
+		label_GameTiming->setText(QString::number(gameData.playerActionTimeoutSec)+" "+tr("sec (action)")+"\n"+QString::number(gameData.delayBetweenHandsSec)+" "+tr("sec (hand delay)"));
 
 		mySession->clientCreateGame(gameData, currentGameName.toUtf8().constData(), myCreateInternetGameDialog->lineEdit_Password->text().toUtf8().constData());
 
 	}
+#ifdef ANDROID
+	this->setFocus();
+#endif
 }
 
 void gameLobbyDialogImpl::joinGame()
@@ -388,13 +461,25 @@ void gameLobbyDialogImpl::refresh(int actionID)
 		myNickListSelectionModel->clearSelection();;
 
 		QStringList headerList;
-		headerList << tr("Game") << tr("Players") << tr("State") << tr("T") << tr("P");
+		headerList << tr("Game") << tr("Players") << tr("State") << tr("T") << tr("P") << tr("Time");;
 		myGameListModel->setHorizontalHeaderLabels(headerList);
-		treeView_GameList->setColumnWidth(0,190);
+
+#ifdef GUI_800x480
+		treeView_GameList->setColumnWidth(0,200); //484px alltogether
 		treeView_GameList->setColumnWidth(1,65);
+		treeView_GameList->setColumnWidth(2,100);
+		treeView_GameList->setColumnWidth(3,20);
+		treeView_GameList->setColumnWidth(4,20);
+		treeView_GameList->setColumnWidth(5,75);
+#else
+		treeView_GameList->setColumnWidth(0,190);
+		treeView_GameList->setColumnWidth(1,55);
 		treeView_GameList->setColumnWidth(2,65);
-		treeView_GameList->setColumnWidth(3,40);
-		treeView_GameList->setColumnWidth(4,40);
+		treeView_GameList->setColumnWidth(3,25);
+		treeView_GameList->setColumnWidth(4,25);
+		treeView_GameList->setColumnWidth(5,30);
+
+#endif
 
 		QStringList headerList2;
 		headerList2 << tr("Available Players");
@@ -408,7 +493,7 @@ void gameLobbyDialogImpl::refresh(int actionID)
 	} else if(actionID == MSG_NET_GAME_CLIENT_SYNCSTART) {
 		waitStartGameMsgBoxTimer->start(2000);
 	} else if(actionID == MSG_NET_GAME_CLIENT_SYNCREJOIN) {
-//		if(this->isVisible()) { //TODO <-- does it work without isVisible???
+		//		if(this->isVisible()) { //TODO <-- does it work without isVisible???
 		//break the autoStartTimer animation
 		autoStartTimer->stop();
 		autoStartTimerOverlay->hide();
@@ -417,7 +502,7 @@ void gameLobbyDialogImpl::refresh(int actionID)
 		waitRejoinStartGameMsgBox->raise();
 		waitRejoinStartGameMsgBox->activateWindow();
 		pushButton_Leave->setDisabled(true);
-//		}
+		//		}
 	}
 }
 
@@ -471,7 +556,7 @@ void gameLobbyDialogImpl::gameSelected(const QModelIndex &index)
 		//		label_MaximumNumberOfPlayers->setText(QString::number(info.data.maxNumberOfPlayers));s
 		updateDialogBlinds(info.data);
 
-		label_TimeoutForPlayerAction->setText(QString::number(info.data.playerActionTimeoutSec));
+		label_GameTiming->setText(QString::number(info.data.playerActionTimeoutSec)+" "+tr("sec (action)")+"\n"+QString::number(info.data.delayBetweenHandsSec)+" "+tr("sec (hand delay)"));
 
 		treeWidget_connectedPlayers->clear();
 		PlayerIdList::const_iterator i = info.players.begin();
@@ -513,6 +598,7 @@ void gameLobbyDialogImpl::updateGameItem(QList <QStandardItem*> itemList, unsign
 			itemList.at(2)->setBackground(QBrush(QColor(0, 255, 0, 127)));
 			itemList.at(3)->setBackground(QBrush(QColor(0, 255, 0, 127)));
 			itemList.at(4)->setBackground(QBrush(QColor(0, 255, 0, 127)));
+			itemList.at(5)->setBackground(QBrush(QColor(0, 255, 0, 127)));
 			break;
 		} else {
 			itemList.at(0)->setData( "", 16);
@@ -521,6 +607,7 @@ void gameLobbyDialogImpl::updateGameItem(QList <QStandardItem*> itemList, unsign
 			itemList.at(2)->setBackground(QBrush());
 			itemList.at(3)->setBackground(QBrush());
 			itemList.at(4)->setBackground(QBrush());
+			itemList.at(5)->setBackground(QBrush());
 		}
 		++i;
 	}
@@ -578,7 +665,14 @@ void gameLobbyDialogImpl::updateGameItem(QList <QStandardItem*> itemList, unsign
 		itemList.at(4)->setData("nonpriv", 16);
 	}
 
-	//	treeView_GameList->sortByColumn(myConfig->readConfigInt("DlgGameLobbyGameListSortingSection"), (Qt::SortOrder)myConfig->readConfigInt("DlgGameLobbyGameListSortingOrder") );
+	itemList.at(5)->setData(QString::number(info.data.playerActionTimeoutSec)+"s/"+QString::number(info.data.delayBetweenHandsSec)+"s", Qt::DisplayRole);
+	QString actionTimeOutString = QString::number(info.data.playerActionTimeoutSec);
+	if(info.data.playerActionTimeoutSec < 10) {
+		actionTimeOutString = "0"+actionTimeOutString;
+	}
+	itemList.at(5)->setData(actionTimeOutString, 16);
+
+	treeView_GameList->sortByColumn(myConfig->readConfigInt("DlgGameLobbyGameListSortingSection"), (Qt::SortOrder)myConfig->readConfigInt("DlgGameLobbyGameListSortingOrder") );
 	refreshGameStats();
 }
 
@@ -590,7 +684,8 @@ void gameLobbyDialogImpl::addGame(unsigned gameId)
 	QStandardItem *item3 = new QStandardItem();
 	QStandardItem *item4 = new QStandardItem();
 	QStandardItem *item5 = new QStandardItem();
-	itemList << item1 << item2 << item3 << item4 << item5;
+	QStandardItem *item6 = new QStandardItem();
+	itemList << item1 << item2 << item3 << item4 << item5 << item6;
 
 	myGameListModel->appendRow(itemList);
 
@@ -604,7 +699,7 @@ void gameLobbyDialogImpl::updateGameMode(unsigned gameId, int /*newMode*/)
 	while (myGameListModel->item(it)) {
 		if (myGameListModel->item(it, 0)->data(Qt::UserRole) == gameId) {
 			QList <QStandardItem*> itemList;
-			itemList << myGameListModel->item(it, 0) << myGameListModel->item(it, 1) << myGameListModel->item(it, 2) << myGameListModel->item(it, 3) << myGameListModel->item(it, 4);
+			itemList << myGameListModel->item(it, 0) << myGameListModel->item(it, 1) << myGameListModel->item(it, 2) << myGameListModel->item(it, 3) << myGameListModel->item(it, 4) << myGameListModel->item(it, 5);
 			updateGameItem(itemList, gameId);
 			break;
 		}
@@ -682,7 +777,7 @@ void gameLobbyDialogImpl::gameAddPlayer(unsigned gameId, unsigned playerId)
 	while (myGameListModel->item(it)) {
 		if (myGameListModel->item(it, 0)->data(Qt::UserRole) == gameId) {
 			QList <QStandardItem*> itemList;
-			itemList << myGameListModel->item(it, 0) << myGameListModel->item(it, 1) << myGameListModel->item(it, 2) << myGameListModel->item(it, 3) << myGameListModel->item(it, 4);
+			itemList << myGameListModel->item(it, 0) << myGameListModel->item(it, 1) << myGameListModel->item(it, 2) << myGameListModel->item(it, 3) << myGameListModel->item(it, 4)  << myGameListModel->item(it, 5);
 
 			updateGameItem(itemList, gameId);
 			break;
@@ -718,7 +813,7 @@ void gameLobbyDialogImpl::gameRemovePlayer(unsigned gameId, unsigned playerId)
 	while (myGameListModel->item(it)) {
 		if (myGameListModel->item(it, 0)->data(Qt::UserRole) == gameId) {
 			QList <QStandardItem*> itemList;
-			itemList << myGameListModel->item(it, 0) << myGameListModel->item(it, 1) << myGameListModel->item(it, 2) << myGameListModel->item(it, 3) << myGameListModel->item(it, 4);
+			itemList << myGameListModel->item(it, 0) << myGameListModel->item(it, 1) << myGameListModel->item(it, 2) << myGameListModel->item(it, 3) << myGameListModel->item(it, 4) << myGameListModel->item(it, 5);
 
 			updateGameItem(itemList, gameId);
 			break;
@@ -760,7 +855,7 @@ void gameLobbyDialogImpl::clearDialog()
 	label_blindsRaiseIntervall->setText("");
 	label_blindsRaiseMode->setText("");
 	label_blindsList->setText("");
-	label_TimeoutForPlayerAction->setText("");
+	label_GameTiming->setText("");
 
 	myGameListModel->clear();
 	myGameListSelectionModel->clear();
@@ -781,13 +876,24 @@ void gameLobbyDialogImpl::clearDialog()
 	pushButton_joinAnyGame->setEnabled(false);
 
 	QStringList headerList;
-	headerList << tr("Game") << tr("Players") << tr("State") << tr("T") << tr("P");
+	headerList << tr("Game") << tr("Players") << tr("State") << tr("T") << tr("P") << tr("Time");
 	myGameListModel->setHorizontalHeaderLabels(headerList);
-	treeView_GameList->setColumnWidth(0,190);
+
+#ifdef GUI_800x480
+	treeView_GameList->setColumnWidth(0,200); //484px alltogether
 	treeView_GameList->setColumnWidth(1,65);
+	treeView_GameList->setColumnWidth(2,100);
+	treeView_GameList->setColumnWidth(3,20);
+	treeView_GameList->setColumnWidth(4,20);
+	treeView_GameList->setColumnWidth(5,75);
+#else
+	treeView_GameList->setColumnWidth(0,190);
+	treeView_GameList->setColumnWidth(1,55);
 	treeView_GameList->setColumnWidth(2,65);
-	treeView_GameList->setColumnWidth(3,40);
-	treeView_GameList->setColumnWidth(4,40);
+	treeView_GameList->setColumnWidth(3,25);
+	treeView_GameList->setColumnWidth(4,25);
+	treeView_GameList->setColumnWidth(5,30);
+#endif
 
 	pushButton_CreateGame->clearFocus();
 	lineEdit_ChatInput->setFocus();
@@ -921,9 +1027,9 @@ void gameLobbyDialogImpl::addConnectedPlayer(unsigned playerId, QString playerNa
 
 	if(this->isVisible() && inGame && myConfig->readConfigInt("PlayNetworkGameNotification")) {
 		if(treeWidget_connectedPlayers->topLevelItemCount() < treeWidget_connectedPlayers->headerItem()->data(0, Qt::UserRole).toInt()) {
-			myW->getMySDLPlayer()->playSound("playerconnected", 0);
+			myW->getMySoundEventHandler()->playSound("playerconnected", 0);
 		} else {
-			myW->getMySDLPlayer()->playSound("onlinegameready", 0);
+			myW->getMySoundEventHandler()->playSound("onlinegameready", 0);
 			showAutoStartTimer();
 		}
 	}
@@ -1135,7 +1241,7 @@ void gameLobbyDialogImpl::joinedGameDialogUpdate()
 	label_SmallBlind->setText(QString("%L1").arg(info.data.firstSmallBlind));
 	label_StartCash->setText(QString("%L1").arg(info.data.startMoney));
 	updateDialogBlinds(info.data);
-	label_TimeoutForPlayerAction->setText(QString::number(info.data.playerActionTimeoutSec));
+	label_GameTiming->setText(QString::number(info.data.playerActionTimeoutSec)+" "+tr("sec (action)")+"\n"+QString::number(info.data.delayBetweenHandsSec)+" "+tr("sec (hand delay)"));
 
 	QTreeWidgetItem *header = treeWidget_connectedPlayers->headerItem();
 	header->setText(0, tr("Connected players - Max. %1").arg(info.data.maxNumberOfPlayers));
@@ -1164,7 +1270,7 @@ void gameLobbyDialogImpl::leftGameDialogUpdate()
 	label_blindsRaiseIntervall->setText("");
 	label_blindsRaiseMode->setText("");
 	label_blindsList->setText("");
-	label_TimeoutForPlayerAction->setText("");
+	label_GameTiming->setText("");
 
 	treeWidget_connectedPlayers->clear();
 	pushButton_StartGame->hide();
@@ -1246,9 +1352,9 @@ void gameLobbyDialogImpl::kickPlayer()
 		QString playerName = item->text(0);
 		if(playerName == QString::fromUtf8(myConfig->readConfigString("MyName").c_str())) {
 			{
-				QMessageBox::warning(this, tr("Server Error"),
-									 tr("You should not kick yourself from this game!"),
-									 QMessageBox::Close);
+				MyMessageBox::warning(this, tr("Server Error"),
+									  tr("You should not kick yourself from this game!"),
+									  QMessageBox::Close);
 			}
 		} else {
 			assert(mySession);
@@ -1301,6 +1407,10 @@ bool gameLobbyDialogImpl::eventFilter(QObject *obj, QEvent *event)
 	} else if (obj == lineEdit_searchForPlayers && focusEvent->gotFocus() && lineEdit_searchForPlayers->text() == tr("search for player ...")) {
 		lineEdit_searchForPlayers->clear();
 		return QDialog::eventFilter(obj, event);
+	} else if (event->type() == QEvent::KeyPress && keyEvent->key() == Qt::Key_Back) {
+		event->ignore();
+		this->reject();
+		return false;
 	} else {
 		// pass the event on to the parent class
 		return QDialog::eventFilter(obj, event);
@@ -1317,7 +1427,9 @@ void gameLobbyDialogImpl::showGameDescription(bool show)
 {
 
 	if(show) {
+#ifndef GUI_800x480
 		label_gameType->show();
+#endif
 		label_gameDesc2->show();
 		label_gameDesc3->show();
 		label_gameDesc4->show();
@@ -1439,6 +1551,7 @@ void gameLobbyDialogImpl::changeGameListFilter(int index)
 		myGameListSortFilterProxyModel->setColumn2RegExp(QRegExp());
 		myGameListSortFilterProxyModel->setColumn3RegExp(QRegExp());
 		myGameListSortFilterProxyModel->setColumn4RegExp(QRegExp());
+		myGameListSortFilterProxyModel->setColumn5RegExp(QRegExp());
 	}
 	break;
 	case 1: {
@@ -1446,6 +1559,7 @@ void gameLobbyDialogImpl::changeGameListFilter(int index)
 		myGameListSortFilterProxyModel->setColumn2RegExp(QRegExp("open", Qt::CaseInsensitive, QRegExp::FixedString));
 		myGameListSortFilterProxyModel->setColumn3RegExp(QRegExp());
 		myGameListSortFilterProxyModel->setColumn4RegExp(QRegExp());
+		myGameListSortFilterProxyModel->setColumn5RegExp(QRegExp());
 	}
 	break;
 	case 2: {
@@ -1453,6 +1567,7 @@ void gameLobbyDialogImpl::changeGameListFilter(int index)
 		myGameListSortFilterProxyModel->setColumn2RegExp(QRegExp("open", Qt::CaseInsensitive, QRegExp::FixedString));
 		myGameListSortFilterProxyModel->setColumn3RegExp(QRegExp());
 		myGameListSortFilterProxyModel->setColumn4RegExp(QRegExp());
+		myGameListSortFilterProxyModel->setColumn5RegExp(QRegExp());
 	}
 	break;
 	case 3: {
@@ -1460,6 +1575,7 @@ void gameLobbyDialogImpl::changeGameListFilter(int index)
 		myGameListSortFilterProxyModel->setColumn2RegExp(QRegExp("open", Qt::CaseInsensitive, QRegExp::FixedString));
 		myGameListSortFilterProxyModel->setColumn3RegExp(QRegExp());
 		myGameListSortFilterProxyModel->setColumn4RegExp(QRegExp("nonpriv", Qt::CaseInsensitive, QRegExp::FixedString));
+		myGameListSortFilterProxyModel->setColumn5RegExp(QRegExp());
 	}
 	break;
 	case 4: {
@@ -1467,6 +1583,7 @@ void gameLobbyDialogImpl::changeGameListFilter(int index)
 		myGameListSortFilterProxyModel->setColumn2RegExp(QRegExp("open", Qt::CaseInsensitive, QRegExp::FixedString));
 		myGameListSortFilterProxyModel->setColumn3RegExp(QRegExp());
 		myGameListSortFilterProxyModel->setColumn4RegExp(QRegExp("private", Qt::CaseInsensitive, QRegExp::FixedString));
+		myGameListSortFilterProxyModel->setColumn5RegExp(QRegExp());
 	}
 	break;
 	case 5: {
@@ -1474,6 +1591,7 @@ void gameLobbyDialogImpl::changeGameListFilter(int index)
 		myGameListSortFilterProxyModel->setColumn2RegExp(QRegExp("open", Qt::CaseInsensitive, QRegExp::FixedString));
 		myGameListSortFilterProxyModel->setColumn3RegExp(QRegExp("ranking", Qt::CaseInsensitive, QRegExp::FixedString));
 		myGameListSortFilterProxyModel->setColumn4RegExp(QRegExp());
+		myGameListSortFilterProxyModel->setColumn5RegExp(QRegExp());
 	}
 	break;
 	default:
@@ -1485,8 +1603,10 @@ void gameLobbyDialogImpl::changeGameListFilter(int index)
 	writeDialogSettings(1);
 
 #ifdef GUI_800x480
-	if(index) treeView_GameList->setStyleSheet("QTreeView { border-radius: 4px; border: 2px solid blue; background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat; color:rgb(0, 0, 0); font: 14px}");
-	else treeView_GameList->setStyleSheet("QTreeView { background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat; color:rgb(0, 0, 0); font: 14px}");
+	if(index) treeView_GameList->setStyleSheet("QTreeView { border-radius: 4px; border: 2px solid blue; background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat; color:rgb(0, 0, 0); font: 20px}");
+	else treeView_GameList->setStyleSheet("QTreeView { background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat; color:rgb(0, 0, 0); font: 20px}");
+
+	treeView_GameList->header()->setStyleSheet("QObject {font: bold 18px}");
 #else
 	if(index) treeView_GameList->setStyleSheet("QTreeView { border-radius: 4px; border: 2px solid blue; background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat;}");
 	else treeView_GameList->setStyleSheet("QTreeView { background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat;}");
@@ -1495,12 +1615,21 @@ void gameLobbyDialogImpl::changeGameListFilter(int index)
 
 void gameLobbyDialogImpl::changeNickListFilter(int state)
 {
+	if(lastNickListFilterState == 0) {
+		myNickListSortFilterProxyModel->setLastFilterStateCountry(false);
+		myNickListSortFilterProxyModel->setLastFilterStateAlpha(true);
+	} else if(lastNickListFilterState == 1) {
+		myNickListSortFilterProxyModel->setLastFilterStateCountry(true);
+		myNickListSortFilterProxyModel->setLastFilterStateAlpha(false);
+	}
+
 	myNickListSortFilterProxyModel->setFilterState(state);
 	myNickListModel->sort(0, Qt::DescendingOrder);
 
 	myNickListSortFilterProxyModel->setFilterRegExp(QString());
 	myNickListSortFilterProxyModel->setFilterKeyColumn(0);
 
+	lastNickListFilterState = state;
 	writeDialogSettings(2);
 }
 
@@ -1553,7 +1682,6 @@ void gameLobbyDialogImpl::showNickListContextMenu(QPoint p)
 			nickListIgnorePlayerAction->setText(tr("Ignore player ..."));
 		}
 
-
 		unsigned gameIdOfPlayer = mySession->getGameIdOfPlayer(playerUid);
 		QString playerInGameInfoString;
 		if(gameIdOfPlayer) {
@@ -1563,6 +1691,15 @@ void gameLobbyDialogImpl::showNickListContextMenu(QPoint p)
 		}
 		nickListPlayerInGameInfo->setText(playerInGameInfoString);
 
+		//prevent admin to total kickban himself
+		if(playerUid == mySession->getClientUniquePlayerId()) {	nickListAdminTotalKickBan->setDisabled(true); }
+		else { nickListAdminTotalKickBan->setEnabled(true);	}
+
+//		check for admin	and remove admin actions for non-admins
+		if(!mySession->getClientPlayerInfo(mySession->getClientUniquePlayerId()).isAdmin) {
+			nickListContextMenu->removeAction(nickListAdminSubMenu->menuAction());
+		}
+
 		//popup a little more to the right to avaoid double click action
 		QPoint tempPoint = p;
 		tempPoint.setX(p.x()+5);
@@ -1570,6 +1707,27 @@ void gameLobbyDialogImpl::showNickListContextMenu(QPoint p)
 	}
 }
 
+void gameLobbyDialogImpl::showGameListContextMenu(QPoint p)
+{
+	if(myGameListModel->rowCount() && myGameListSelectionModel->currentIndex().isValid()) {
+
+		assert(mySession);
+		unsigned selectedGameId = myGameListSelectionModel->selectedRows().first().data(Qt::UserRole).toUInt();
+		if(selectedGameId == mySession->getClientCurrentGameId()) { gameListAdminCloseGame->setDisabled(true); }
+		else { gameListAdminCloseGame->setEnabled(true); }
+
+//		check for admin	and remove admin actions for non-admins
+		if(!mySession->getClientPlayerInfo(mySession->getClientUniquePlayerId()).isAdmin) {
+			gameListContextMenu->removeAction(gameListAdminSubMenu->menuAction());
+		}
+
+		//popup a little more to the right to avaoid double click action
+		QPoint tempPoint = p;
+		tempPoint.setX(p.x()+5);
+		gameListContextMenu->popup(treeView_GameList->mapToGlobal(tempPoint));
+	}
+}
+
 void gameLobbyDialogImpl::invitePlayerToCurrentGame()
 {
 	if(myNickListSelectionModel->currentIndex().isValid()) {
@@ -1582,7 +1740,7 @@ void gameLobbyDialogImpl::showInfoMsgBox()
 	switch(infoMsgToShowId) {
 	case 2: {
 		inviteOnlyInfoMsgBox->setModal(false);
-		inviteOnlyInfoMsgBox->show(2, tr("You have entered a game with type \"invite-only\".\nFeel free to invite other players by right-clicking on their nick in the available players list."), tr("PokerTH - Info Message"), QPixmap(":/gfx/ktip.png"), QDialogButtonBox::Ok, true);
+		inviteOnlyInfoMsgBox->show(INFO_AFTER_JOIN_INVITE_GAME, tr("You have entered a game with type \"invite-only\".\nFeel free to invite other players by right-clicking on their nick in the available players list."), tr("PokerTH - Info Message"), QPixmap(":/gfx/ktip.png"), QDialogButtonBox::Ok, true);
 	}
 	break;
 	default:
@@ -1601,7 +1759,7 @@ void gameLobbyDialogImpl::showInvitationDialog(unsigned gameId, unsigned playerI
 		inviteDialogIsCurrentlyShown = true;
 
 		myMessageDialogImpl dialog(myConfig, this);
-		if(dialog.exec(3, tr("You have been invited to the game <b>%1</b> by <b>%2</b>.<br>Would you like to join this game?").arg(QString::fromUtf8(mySession->getClientGameInfo(gameId).name.c_str())).arg(QString::fromUtf8(mySession->getClientPlayerInfo(playerIdFrom).playerName.c_str())), tr("PokerTH - Info Message"), QPixmap(":/gfx/list_add_user_64.png"), QDialogButtonBox::Yes|QDialogButtonBox::No, false)) {
+		if(dialog.exec(JOIN_INVITE_GAME_QUESTION, tr("You have been invited to the game <b>%1</b> by <b>%2</b>.<br>Would you like to join this game?").arg(QString::fromUtf8(mySession->getClientGameInfo(gameId).name.c_str())).arg(QString::fromUtf8(mySession->getClientPlayerInfo(playerIdFrom).playerName.c_str())), tr("PokerTH - Info Message"), QPixmap(":/gfx/list_add_user_64.png"), QDialogButtonBox::Yes|QDialogButtonBox::No, false)) {
 
 			mySession->acceptGameInvitation(gameId);
 			inviteDialogIsCurrentlyShown = false;
@@ -1655,7 +1813,7 @@ void gameLobbyDialogImpl::putPlayerOnIgnoreList()
 		if(!playerIsOnIgnoreList(playerId)) {
 
 			myMessageDialogImpl dialog(myConfig, this);
-			if(dialog.exec(4, tr("You will no longer receive chat messages or game invitations from this user.<br>Do you really want to put player <b>%1</b> on your ignore list?").arg(QString::fromUtf8(mySession->getClientPlayerInfo(playerId).playerName.c_str())), tr("PokerTH - Question"), QPixmap(":/gfx/im-ban-user_64.png"), QDialogButtonBox::Yes|QDialogButtonBox::No, false ) == QDialog::Accepted) {
+			if(dialog.exec(INGNORE_PLAYER_QUESTION, tr("You will no longer receive chat messages or game invitations from this user.<br>Do you really want to put player <b>%1</b> on your ignore list?").arg(QString::fromUtf8(mySession->getClientPlayerInfo(playerId).playerName.c_str())), tr("PokerTH - Question"), QPixmap(":/gfx/im-ban-user_64.png"), QDialogButtonBox::Yes|QDialogButtonBox::No, false ) == QDialog::Accepted) {
 
 				list<std::string> playerIgnoreList = myConfig->readConfigStringList("PlayerIgnoreList");
 				playerIgnoreList.push_back(QString("%1").arg(QString::fromUtf8(mySession->getClientPlayerInfo(playerId).playerName.c_str())).toUtf8().constData());
@@ -1681,7 +1839,13 @@ void gameLobbyDialogImpl::showAutoStartTimer()
 	autoStartTimerOverlay->setGeometry(((scrollArea_gameInfos->geometry().width()-190)/2), ((scrollArea_gameInfos->geometry().height()-50)/2), 190, 50);
 
 	QString string(tr("The game will start in<br><b>%1</b> seconds.").arg(6));
-	autoStartTimerOverlay->setText("<span style='color:#008B00; font-size:9pt;'>"+string+"</span>");
+	QString fontsize;
+#ifdef ANDROID
+	fontsize="16px";
+#else
+	fontsize="10px";
+#endif
+	autoStartTimerOverlay->setText("<span style='color:#008B00; font-size:"+fontsize+";'>"+string+"</span>");
 	autoStartTimerCounter = 6;
 	autoStartTimer->start(1000);
 
@@ -1692,7 +1856,13 @@ void gameLobbyDialogImpl::updateAutoStartTimer()
 	--autoStartTimerCounter;
 	if(autoStartTimerCounter) {
 		QString string(tr("The game will start in<br><b>%1</b> seconds.").arg(autoStartTimerCounter));
-		autoStartTimerOverlay->setText("<span style='color:#008B00; font-size:9pt;'>"+string+"</span>");
+		QString fontsize;
+#ifdef ANDROID
+		fontsize="16px";
+#else
+		fontsize="10px";
+#endif
+		autoStartTimerOverlay->setText("<span style='color:#008B00; font-size:"+fontsize+";'>"+string+"</span>");
 	} else {
 		autoStartTimer->stop();
 		autoStartTimerOverlay->hide();
@@ -2010,3 +2180,52 @@ void gameLobbyDialogImpl::closeAllChildDialogs()
 	waitStartGameMsgBox->hide();
 	waitRejoinStartGameMsgBox->hide();
 }
+
+void gameLobbyDialogImpl::reportBadGameName()
+{
+	assert(mySession);
+	if (myGameListSelectionModel->hasSelection()) {
+		unsigned gameId = myGameListSelectionModel->selectedRows().first().data(Qt::UserRole).toUInt();
+		GameInfo info(mySession->getClientGameInfo(gameId));
+
+		int ret = MyMessageBox::question(this, tr("PokerTH - Question"),
+										 tr("Are you sure you want to report the game name:\n\"%1\" as inappropriate?").arg(QString::fromUtf8(info.name.c_str())), QMessageBox::Yes | QMessageBox::No);
+
+		if(ret == QMessageBox::Yes) {
+			mySession->reportBadGameName(gameId);
+		}
+	}
+}
+
+
+void gameLobbyDialogImpl::adminActionCloseGame()
+{
+	assert(mySession);
+	if (myGameListSelectionModel->hasSelection()) {
+		unsigned gameId = myGameListSelectionModel->selectedRows().first().data(Qt::UserRole).toUInt();
+		GameInfo info(mySession->getClientGameInfo(gameId));
+
+		int ret = MyMessageBox::question(this, tr("PokerTH - Question"),
+										 tr("Are you sure you want to close the game:\n\"%1\"?").arg(QString::fromUtf8(info.name.c_str())), QMessageBox::Yes | QMessageBox::No);
+
+		if (ret == QMessageBox::Yes) {
+			mySession->adminActionCloseGame(gameId);
+		}
+	}
+}
+
+void gameLobbyDialogImpl::adminActionTotalKickBan()
+{
+	assert(mySession);
+	if (myNickListSelectionModel->hasSelection()) {
+		unsigned playerId = myNickListSelectionModel->selectedRows().first().data(Qt::UserRole).toUInt();
+		PlayerInfo info(mySession->getClientPlayerInfo(playerId));
+
+		int ret = MyMessageBox::question(this, tr("PokerTH - Question"),
+										 tr("Are you sure you want to total kickban the player: \"%1\"?").arg(QString::fromUtf8(info.playerName.c_str())), QMessageBox::Yes | QMessageBox::No);
+
+		if(ret == QMessageBox::Yes) {
+			mySession->adminActionBanPlayer(playerId);
+		}
+	}
+}
