@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,6 +14,19 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 #ifndef SETTINGSDIALOGIMPL_H
 #define SETTINGSDIALOGIMPL_H
@@ -38,6 +51,7 @@ class selectAvatarDialogImpl;
 class manualBlindsOrderDialogImpl;
 class MyStyleListItem;
 class guiLog;
+class FlickCharm;
 
 class settingsDialogImpl: public QDialog, public Ui::settingsDialog
 {
@@ -112,12 +126,6 @@ public slots:
 	void addCardDeckStyle();
 	void removeCardDeckStyle();
 	void removePlayerFromIgnoredPlayersList();
-	void refreshLogFileList();
-	void deleteLogFile();
-	void exportLogToHtml();
-	void exportLogToTxt();
-	void saveLogFileAs();
-	void showLogFilePreview();
 	void resetSettings();
 
 private:
@@ -139,7 +147,6 @@ private:
 	std::list<std::string> myCardDeckStylesList;
 
 	ConfigFile* myConfig;
-	guiLog* myGuiLog;
 	selectAvatarDialogImpl *mySelectAvatarDialogImpl;
 	manualBlindsOrderDialogImpl *myManualBlindsOrderDialog;
 
@@ -148,6 +155,8 @@ private:
 	bool languageIsChanged;
 	bool calledIngame;
 	int changedLanguageIndex;
+	guiLog *myGuiLog;
+	FlickCharm *fc;
 };
 
 #endif
